Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb

Overview

Defines a field that has a display name, data type, and other configuration options. This field defines the kind of metadata that may be set on a Drive item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaField

Returns a new instance of GoogleAppsDriveLabelsV2betaField.



1419
1420
1421
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_capabilitiesGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldAppliedCapabilities

The capabilities related to this field on applied metadata. Corresponds to the JSON property appliedCapabilities



1306
1307
1308
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1306

def applied_capabilities
  @applied_capabilities
end

#create_timeString

Output only. The time this field was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1311
1312
1313
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1311

def create_time
  @create_time
end

#creatorGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo

Information about a user. Corresponds to the JSON property creator



1316
1317
1318
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1316

def creator
  @creator
end

#date_optionsGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldDateOptions

Options for the date field type. Corresponds to the JSON property dateOptions



1321
1322
1323
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1321

def date_options
  @date_options
end

#disable_timeString

Output only. The time this field was disabled. This value has no meaning when the field is not disabled. Corresponds to the JSON property disableTime

Returns:

  • (String)


1327
1328
1329
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1327

def disable_time
  @disable_time
end

#disablerGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo

Information about a user. Corresponds to the JSON property disabler



1332
1333
1334
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1332

def disabler
  @disabler
end

#display_hintsGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldDisplayHints

UI display hints for rendering a field. Corresponds to the JSON property displayHints



1337
1338
1339
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1337

def display_hints
  @display_hints
end

#idString

Output only. The key of a field, unique within a label or library. This value is autogenerated. Matches the regex: ([a-zA-Z0-9])+. Corresponds to the JSON property id

Returns:

  • (String)


1343
1344
1345
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1343

def id
  @id
end

#integer_optionsGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldIntegerOptions

Options for the Integer field type. Corresponds to the JSON property integerOptions



1348
1349
1350
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1348

def integer_options
  @integer_options
end

#lifecycleGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLifecycle

The lifecycle state of an object, such as label, field, or choice. For more information, see Label lifecycle. The lifecycle enforces the following transitions: * UNPUBLISHED_DRAFT (starting state) * UNPUBLISHED_DRAFT -> PUBLISHED * UNPUBLISHED_DRAFT -> (Deleted) * PUBLISHED -> DISABLED * DISABLED -> PUBLISHED * DISABLED -> (Deleted) The published and disabled states have some distinct characteristics: * Published: Some kinds of changes might be made to an object in this state, in which case has_unpublished_changes will be true. Also, some kinds of changes aren't permitted. Generally, any change that would invalidate or cause new restrictions on existing metadata related to the label are rejected. * Disabled: When disabled, the configured DisabledPolicy takes effect. Corresponds to the JSON property lifecycle



1364
1365
1366
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1364

def lifecycle
  @lifecycle
end

#lock_statusGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLockStatus

Contains information about whether a label component should be considered locked. Corresponds to the JSON property lockStatus



1370
1371
1372
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1370

def lock_status
  @lock_status
end

#propertiesGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldProperties

The basic properties of the field. Corresponds to the JSON property properties



1375
1376
1377
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1375

def properties
  @properties
end

#publisherGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo

Information about a user. Corresponds to the JSON property publisher



1380
1381
1382
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1380

def publisher
  @publisher
end

#query_keyString

Output only. The key to use when constructing Drive search queries to find files based on values defined for this field on files. For example, " query_key > 2001-01-01". Corresponds to the JSON property queryKey

Returns:

  • (String)


1387
1388
1389
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1387

def query_key
  @query_key
end

#schema_capabilitiesGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSchemaCapabilities

The capabilities related to this field when editing the field. Corresponds to the JSON property schemaCapabilities



1392
1393
1394
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1392

def schema_capabilities
  @schema_capabilities
end

#selection_optionsGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptions

Options for the selection field type. Corresponds to the JSON property selectionOptions



1397
1398
1399
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1397

def selection_options
  @selection_options
end

#text_optionsGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldTextOptions

Options for the Text field type. Corresponds to the JSON property textOptions



1402
1403
1404
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1402

def text_options
  @text_options
end

#update_timeString

Output only. The time this field was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1407
1408
1409
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1407

def update_time
  @update_time
end

#updaterGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo

Information about a user. Corresponds to the JSON property updater



1412
1413
1414
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1412

def updater
  @updater
end

#user_optionsGoogle::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldUserOptions

Options for the user field type. Corresponds to the JSON property userOptions



1417
1418
1419
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1417

def user_options
  @user_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1424

def update!(**args)
  @applied_capabilities = args[:applied_capabilities] if args.key?(:applied_capabilities)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @date_options = args[:date_options] if args.key?(:date_options)
  @disable_time = args[:disable_time] if args.key?(:disable_time)
  @disabler = args[:disabler] if args.key?(:disabler)
  @display_hints = args[:display_hints] if args.key?(:display_hints)
  @id = args[:id] if args.key?(:id)
  @integer_options = args[:integer_options] if args.key?(:integer_options)
  @lifecycle = args[:lifecycle] if args.key?(:lifecycle)
  @lock_status = args[:lock_status] if args.key?(:lock_status)
  @properties = args[:properties] if args.key?(:properties)
  @publisher = args[:publisher] if args.key?(:publisher)
  @query_key = args[:query_key] if args.key?(:query_key)
  @schema_capabilities = args[:schema_capabilities] if args.key?(:schema_capabilities)
  @selection_options = args[:selection_options] if args.key?(:selection_options)
  @text_options = args[:text_options] if args.key?(:text_options)
  @update_time = args[:update_time] if args.key?(:update_time)
  @updater = args[:updater] if args.key?(:updater)
  @user_options = args[:user_options] if args.key?(:user_options)
end