Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldProperties
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
The basic properties of the field.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#insert_before_field ⇒ String
Input only.
-
#required ⇒ Boolean
(also: #required?)
Whether the field should be marked as required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldProperties
constructor
A new instance of GoogleAppsDriveLabelsV2betaFieldProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldProperties
Returns a new instance of GoogleAppsDriveLabelsV2betaFieldProperties.
1709 1710 1711 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The display text to show in the UI identifying this field.
Corresponds to the JSON property displayName
1695 1696 1697 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1695 def display_name @display_name end |
#insert_before_field ⇒ String
Input only. Insert or move this field before the indicated field. If empty,
the field is placed at the end of the list.
Corresponds to the JSON property insertBeforeField
1701 1702 1703 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1701 def insert_before_field @insert_before_field end |
#required ⇒ Boolean Also known as: required?
Whether the field should be marked as required.
Corresponds to the JSON property required
1706 1707 1708 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1706 def required @required end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1714 1715 1716 1717 1718 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1714 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @insert_before_field = args[:insert_before_field] if args.key?(:insert_before_field) @required = args[:required] if args.key?(:required) end |