Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSchemaCapabilities

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb

Overview

The capabilities related to this field when editing the field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldSchemaCapabilities

Returns a new instance of GoogleAppsDriveLabelsV2betaFieldSchemaCapabilities.



1752
1753
1754
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_deleteBoolean Also known as: can_delete?

Whether the user can delete this field. The user must have permission and the field must be deprecated. Corresponds to the JSON property canDelete

Returns:

  • (Boolean)


1729
1730
1731
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1729

def can_delete
  @can_delete
end

#can_disableBoolean Also known as: can_disable?

Whether the user can disable this field. The user must have permission and this field must not already be disabled. Corresponds to the JSON property canDisable

Returns:

  • (Boolean)


1736
1737
1738
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1736

def can_disable
  @can_disable
end

#can_enableBoolean Also known as: can_enable?

Whether the user can enable this field. The user must have permission and this field must be disabled. Corresponds to the JSON property canEnable

Returns:

  • (Boolean)


1743
1744
1745
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1743

def can_enable
  @can_enable
end

#can_updateBoolean Also known as: can_update?

Whether the user can change this field. Corresponds to the JSON property canUpdate

Returns:

  • (Boolean)


1749
1750
1751
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1749

def can_update
  @can_update
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1757
1758
1759
1760
1761
1762
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1757

def update!(**args)
  @can_delete = args[:can_delete] if args.key?(:can_delete)
  @can_disable = args[:can_disable] if args.key?(:can_disable)
  @can_enable = args[:can_enable] if args.key?(:can_enable)
  @can_update = args[:can_update] if args.key?(:can_update)
end