Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
The capabilities related to this choice on applied metadata.
Instance Attribute Summary collapse
-
#can_read ⇒ Boolean
(also: #can_read?)
Whether the user can read related applied metadata on items.
-
#can_search ⇒ Boolean
(also: #can_search?)
Whether the user can use this choice in search queries.
-
#can_select ⇒ Boolean
(also: #can_select?)
Whether the user can select this choice on an item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities
constructor
A new instance of GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities
Returns a new instance of GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities.
1931 1932 1933 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_read ⇒ Boolean Also known as: can_read?
Whether the user can read related applied metadata on items.
Corresponds to the JSON property canRead
1916 1917 1918 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1916 def can_read @can_read end |
#can_search ⇒ Boolean Also known as: can_search?
Whether the user can use this choice in search queries.
Corresponds to the JSON property canSearch
1922 1923 1924 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1922 def can_search @can_search end |
#can_select ⇒ Boolean Also known as: can_select?
Whether the user can select this choice on an item.
Corresponds to the JSON property canSelect
1928 1929 1930 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1928 def can_select @can_select end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1936 1937 1938 1939 1940 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1936 def update!(**args) @can_read = args[:can_read] if args.key?(:can_read) @can_search = args[:can_search] if args.key?(:can_search) @can_select = args[:can_select] if args.key?(:can_select) end |