Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelAppliedLabelPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb

Overview

Behavior of this label when it's applied to Drive items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelAppliedLabelPolicy

Returns a new instance of GoogleAppsDriveLabelsV2betaLabelAppliedLabelPolicy.



2371
2372
2373
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#copy_modeString

Indicates how the applied label and field values should be copied when a Drive item is copied. Corresponds to the JSON property copyMode

Returns:

  • (String)


2369
2370
2371
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2369

def copy_mode
  @copy_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2376
2377
2378
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2376

def update!(**args)
  @copy_mode = args[:copy_mode] if args.key?(:copy_mode)
end