Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelDisplayHints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb

Overview

The UI display hints for rendering the label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelDisplayHints

Returns a new instance of GoogleAppsDriveLabelsV2betaLabelDisplayHints.



2409
2410
2411
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

Whether the label should be shown in the UI as disabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


2388
2389
2390
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2388

def disabled
  @disabled
end

#hidden_in_searchBoolean Also known as: hidden_in_search?

This label should be hidden in the search menu when searching for Drive items. Corresponds to the JSON property hiddenInSearch

Returns:

  • (Boolean)


2394
2395
2396
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2394

def hidden_in_search
  @hidden_in_search
end

#priorityFixnum

The order to display labels in a list. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


2400
2401
2402
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2400

def priority
  @priority
end

#shown_in_applyBoolean Also known as: shown_in_apply?

This label should be shown in the apply menu when applying values to a Drive item. Corresponds to the JSON property shownInApply

Returns:

  • (Boolean)


2406
2407
2408
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2406

def shown_in_apply
  @shown_in_apply
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2414
2415
2416
2417
2418
2419
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2414

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
  @hidden_in_search = args[:hidden_in_search] if args.key?(:hidden_in_search)
  @priority = args[:priority] if args.key?(:priority)
  @shown_in_apply = args[:shown_in_apply] if args.key?(:shown_in_apply)
end