Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelEnabledAppSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb

Overview

Describes the Google Workspace apps in which the label can be used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelEnabledAppSettings

Returns a new instance of GoogleAppsDriveLabelsV2betaLabelEnabledAppSettings.



2431
2432
2433
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabled_appsArray<Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelEnabledAppSettingsEnabledApp>

Optional. The list of apps where the label can be used. Corresponds to the JSON property enabledApps



2429
2430
2431
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2429

def enabled_apps
  @enabled_apps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2436
2437
2438
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2436

def update!(**args)
  @enabled_apps = args[:enabled_apps] if args.key?(:enabled_apps)
end