Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelLockCapabilities
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelLockCapabilities
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
A description of a user's capabilities on a label lock.
Instance Attribute Summary collapse
-
#can_view_policy ⇒ Boolean
(also: #can_view_policy?)
True if the user is authorized to view the policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelLockCapabilities
constructor
A new instance of GoogleAppsDriveLabelsV2betaLabelLockCapabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelLockCapabilities
Returns a new instance of GoogleAppsDriveLabelsV2betaLabelLockCapabilities.
2592 2593 2594 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_view_policy ⇒ Boolean Also known as: can_view_policy?
True if the user is authorized to view the policy.
Corresponds to the JSON property canViewPolicy
2589 2590 2591 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2589 def can_view_policy @can_view_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2597 2598 2599 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2597 def update!(**args) @can_view_policy = args[:can_view_policy] if args.key?(:can_view_policy) end |