Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelPermission
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelPermission
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
The permission that applies to a principal (user, group, audience) on a label.
Instance Attribute Summary collapse
-
#audience ⇒ String
Audience to grant a role to.
-
#email ⇒ String
Specifies the email address for a user or group principal.
-
#group ⇒ String
Group resource name.
-
#name ⇒ String
Resource name of this permission.
-
#person ⇒ String
Person resource name.
-
#role ⇒ String
The role the principal should have.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelPermission
constructor
A new instance of GoogleAppsDriveLabelsV2betaLabelPermission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelPermission
Returns a new instance of GoogleAppsDriveLabelsV2betaLabelPermission.
2641 2642 2643 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ String
Audience to grant a role to. The magic value of audiences/default may be
used to apply the role to the default audience in the context of the
organization that owns the label.
Corresponds to the JSON property audience
2611 2612 2613 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2611 def audience @audience end |
#email ⇒ String
Specifies the email address for a user or group principal. Not populated for
audience principals. User and group permissions may only be inserted using an
email address. On update requests, if email address is specified, no principal
should be specified.
Corresponds to the JSON property email
2619 2620 2621 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2619 def email @email end |
#group ⇒ String
Group resource name.
Corresponds to the JSON property group
2624 2625 2626 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2624 def group @group end |
#name ⇒ String
Resource name of this permission.
Corresponds to the JSON property name
2629 2630 2631 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2629 def name @name end |
#person ⇒ String
Person resource name.
Corresponds to the JSON property person
2634 2635 2636 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2634 def person @person end |
#role ⇒ String
The role the principal should have.
Corresponds to the JSON property role
2639 2640 2641 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2639 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2646 2647 2648 2649 2650 2651 2652 2653 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2646 def update!(**args) @audience = args[:audience] if args.key?(:audience) @email = args[:email] if args.key?(:email) @group = args[:group] if args.key?(:group) @name = args[:name] if args.key?(:name) @person = args[:person] if args.key?(:person) @role = args[:role] if args.key?(:role) end |