Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUpdateLabelCopyModeRequest
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUpdateLabelCopyModeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
Request to update the CopyMode of the given label. Changes to this policy
aren't revisioned, don't require publishing, and take effect immediately. \
Instance Attribute Summary collapse
-
#copy_mode ⇒ String
Required.
-
#language_code ⇒ String
The BCP-47 language code to use for evaluating localized field labels.
-
#use_admin_access ⇒ Boolean
(also: #use_admin_access?)
Set to
truein order to use the user's admin credentials. -
#view ⇒ String
When specified, only certain fields belonging to the indicated view will be returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaUpdateLabelCopyModeRequest
constructor
A new instance of GoogleAppsDriveLabelsV2betaUpdateLabelCopyModeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaUpdateLabelCopyModeRequest
Returns a new instance of GoogleAppsDriveLabelsV2betaUpdateLabelCopyModeRequest.
3078 3079 3080 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#copy_mode ⇒ String
Required. Indicates how the applied label and field values should be copied
when a Drive item is copied.
Corresponds to the JSON property copyMode
3057 3058 3059 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3057 def copy_mode @copy_mode end |
#language_code ⇒ String
The BCP-47 language code to use for evaluating localized field labels. When
not specified, values in the default configured language will be used.
Corresponds to the JSON property languageCode
3063 3064 3065 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3063 def language_code @language_code end |
#use_admin_access ⇒ Boolean Also known as: use_admin_access?
Set to true in order to use the user's admin credentials. The server will
verify the user is an admin for the label before allowing access.
Corresponds to the JSON property useAdminAccess
3069 3070 3071 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3069 def use_admin_access @use_admin_access end |
#view ⇒ String
When specified, only certain fields belonging to the indicated view will be
returned.
Corresponds to the JSON property view
3076 3077 3078 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3076 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3083 3084 3085 3086 3087 3088 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3083 def update!(**args) @copy_mode = args[:copy_mode] if args.key?(:copy_mode) @language_code = args[:language_code] if args.key?(:language_code) @use_admin_access = args[:use_admin_access] if args.key?(:use_admin_access) @view = args[:view] if args.key?(:view) end |