Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUpdateLabelPermissionRequest
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUpdateLabelPermissionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
Updates a label permission. Permissions affect the label resource as a whole, aren't revisioned, and don't require publishing.
Instance Attribute Summary collapse
-
#label_permission ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelPermission
The permission that applies to a principal (user, group, audience) on a label.
-
#parent ⇒ String
Required.
-
#use_admin_access ⇒ Boolean
(also: #use_admin_access?)
Set to
truein order to use the user's admin credentials.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaUpdateLabelPermissionRequest
constructor
A new instance of GoogleAppsDriveLabelsV2betaUpdateLabelPermissionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaUpdateLabelPermissionRequest
Returns a new instance of GoogleAppsDriveLabelsV2betaUpdateLabelPermissionRequest.
3156 3157 3158 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#label_permission ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelPermission
The permission that applies to a principal (user, group, audience) on a label.
Corresponds to the JSON property labelPermission
3142 3143 3144 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3142 def @label_permission end |
#parent ⇒ String
Required. The parent label resource name.
Corresponds to the JSON property parent
3147 3148 3149 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3147 def parent @parent end |
#use_admin_access ⇒ Boolean Also known as: use_admin_access?
Set to true in order to use the user's admin credentials. The server will
verify the user is an admin for the label before allowing access.
Corresponds to the JSON property useAdminAccess
3153 3154 3155 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3153 def use_admin_access @use_admin_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3161 3162 3163 3164 3165 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3161 def update!(**args) @label_permission = args[:label_permission] if args.key?(:label_permission) @parent = args[:parent] if args.key?(:parent) @use_admin_access = args[:use_admin_access] if args.key?(:use_admin_access) end |