Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserCapabilities
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserCapabilities
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
The capabilities of a user.
Instance Attribute Summary collapse
-
#can_access_label_manager ⇒ Boolean
(also: #can_access_label_manager?)
Output only.
-
#can_administrate_labels ⇒ Boolean
(also: #can_administrate_labels?)
Output only.
-
#can_create_admin_labels ⇒ Boolean
(also: #can_create_admin_labels?)
Output only.
-
#can_create_shared_labels ⇒ Boolean
(also: #can_create_shared_labels?)
Output only.
-
#name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaUserCapabilities
constructor
A new instance of GoogleAppsDriveLabelsV2betaUserCapabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaUserCapabilities
Returns a new instance of GoogleAppsDriveLabelsV2betaUserCapabilities.
3202 3203 3204 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_access_label_manager ⇒ Boolean Also known as: can_access_label_manager?
Output only. Whether the user is allowed access to the label manager.
Corresponds to the JSON property canAccessLabelManager
3175 3176 3177 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3175 def can_access_label_manager @can_access_label_manager end |
#can_administrate_labels ⇒ Boolean Also known as: can_administrate_labels?
Output only. Whether the user is an administrator for the shared labels
feature.
Corresponds to the JSON property canAdministrateLabels
3182 3183 3184 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3182 def can_administrate_labels @can_administrate_labels end |
#can_create_admin_labels ⇒ Boolean Also known as: can_create_admin_labels?
Output only. Whether the user is allowed to create admin labels.
Corresponds to the JSON property canCreateAdminLabels
3188 3189 3190 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3188 def can_create_admin_labels @can_create_admin_labels end |
#can_create_shared_labels ⇒ Boolean Also known as:
Output only. Whether the user is allowed to create shared labels.
Corresponds to the JSON property canCreateSharedLabels
3194 3195 3196 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3194 def can_create_shared_labels @can_create_shared_labels end |
#name ⇒ String
Output only. Resource name for the user capabilities.
Corresponds to the JSON property name
3200 3201 3202 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3200 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3207 3208 3209 3210 3211 3212 3213 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3207 def update!(**args) @can_access_label_manager = args[:can_access_label_manager] if args.key?(:can_access_label_manager) @can_administrate_labels = args[:can_administrate_labels] if args.key?(:can_administrate_labels) @can_create_admin_labels = args[:can_create_admin_labels] if args.key?(:can_create_admin_labels) @can_create_shared_labels = args[:can_create_shared_labels] if args.key?(:can_create_shared_labels) @name = args[:name] if args.key?(:name) end |