Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaWriteControl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb

Overview

Provides control over how write requests are executed. When not specified, the last write wins.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaWriteControl

Returns a new instance of GoogleAppsDriveLabelsV2betaWriteControl.



3268
3269
3270
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#required_revision_idString

The revision ID of the label that the write request will be applied to. If this isn't the latest revision of the label, the request will not be processed and will return a 400 Bad Request error. Corresponds to the JSON property requiredRevisionId

Returns:

  • (String)


3266
3267
3268
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3266

def required_revision_id
  @required_revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3273
3274
3275
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3273

def update!(**args)
  @required_revision_id = args[:required_revision_id] if args.key?(:required_revision_id)
end