Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
Selection field choice.
Instance Attribute Summary collapse
-
#applied_capabilities ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities
The capabilities related to this choice on applied metadata.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
-
#disable_time ⇒ String
Output only.
-
#disabler ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
-
#display_hints ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceDisplayHints
UI display hints for rendering an option.
-
#id ⇒ String
The unique value of the choice.
-
#lifecycle ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLifecycle
The lifecycle state of an object, such as label, field, or choice.
-
#lock_status ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLockStatus
Contains information about whether a label component should be considered locked.
-
#properties ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties
Basic properties of the choice.
-
#publish_time ⇒ String
Output only.
-
#publisher ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
-
#schema_capabilities ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceSchemaCapabilities
The capabilities related to this choice when editing the choice.
-
#update_time ⇒ String
Output only.
-
#updater ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice
constructor
A new instance of GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice
Returns a new instance of GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice.
1885 1886 1887 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_capabilities ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities
The capabilities related to this choice on applied metadata.
Corresponds to the JSON property appliedCapabilities
1798 1799 1800 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1798 def applied_capabilities @applied_capabilities end |
#create_time ⇒ String
Output only. The time this choice was created.
Corresponds to the JSON property createTime
1803 1804 1805 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1803 def create_time @create_time end |
#creator ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
Corresponds to the JSON property creator
1808 1809 1810 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1808 def creator @creator end |
#disable_time ⇒ String
Output only. The time this choice was disabled. This value has no meaning when
the choice is not disabled.
Corresponds to the JSON property disableTime
1814 1815 1816 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1814 def disable_time @disable_time end |
#disabler ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
Corresponds to the JSON property disabler
1819 1820 1821 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1819 def disabler @disabler end |
#display_hints ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceDisplayHints
UI display hints for rendering an option.
Corresponds to the JSON property displayHints
1824 1825 1826 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1824 def display_hints @display_hints end |
#id ⇒ String
The unique value of the choice. This ID is autogenerated. Matches the regex: (
[a-zA-Z0-9_])+.
Corresponds to the JSON property id
1830 1831 1832 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1830 def id @id end |
#lifecycle ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLifecycle
The lifecycle state of an object, such as label, field, or choice. For more
information, see Label lifecycle. The lifecycle enforces the following
transitions: * UNPUBLISHED_DRAFT (starting state) * UNPUBLISHED_DRAFT ->
PUBLISHED * UNPUBLISHED_DRAFT -> (Deleted) * PUBLISHED -> DISABLED *
DISABLED -> PUBLISHED * DISABLED -> (Deleted) The published and disabled
states have some distinct characteristics: * Published: Some kinds of
changes might be made to an object in this state, in which case
has_unpublished_changes will be true. Also, some kinds of changes aren't
permitted. Generally, any change that would invalidate or cause new
restrictions on existing metadata related to the label are rejected. *
Disabled: When disabled, the configured DisabledPolicy takes effect.
Corresponds to the JSON property lifecycle
1846 1847 1848 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1846 def lifecycle @lifecycle end |
#lock_status ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLockStatus
Contains information about whether a label component should be considered
locked.
Corresponds to the JSON property lockStatus
1852 1853 1854 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1852 def lock_status @lock_status end |
#properties ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties
Basic properties of the choice.
Corresponds to the JSON property properties
1857 1858 1859 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1857 def properties @properties end |
#publish_time ⇒ String
Output only. The time this choice was published. This value has no meaning
when the choice is not published.
Corresponds to the JSON property publishTime
1863 1864 1865 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1863 def publish_time @publish_time end |
#publisher ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
Corresponds to the JSON property publisher
1868 1869 1870 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1868 def publisher @publisher end |
#schema_capabilities ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceSchemaCapabilities
The capabilities related to this choice when editing the choice.
Corresponds to the JSON property schemaCapabilities
1873 1874 1875 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1873 def schema_capabilities @schema_capabilities end |
#update_time ⇒ String
Output only. The time this choice was updated last.
Corresponds to the JSON property updateTime
1878 1879 1880 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1878 def update_time @update_time end |
#updater ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
Corresponds to the JSON property updater
1883 1884 1885 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1883 def updater @updater end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 1890 def update!(**args) @applied_capabilities = args[:applied_capabilities] if args.key?(:applied_capabilities) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @disable_time = args[:disable_time] if args.key?(:disable_time) @disabler = args[:disabler] if args.key?(:disabler) @display_hints = args[:display_hints] if args.key?(:display_hints) @id = args[:id] if args.key?(:id) @lifecycle = args[:lifecycle] if args.key?(:lifecycle) @lock_status = args[:lock_status] if args.key?(:lock_status) @properties = args[:properties] if args.key?(:properties) @publish_time = args[:publish_time] if args.key?(:publish_time) @publisher = args[:publisher] if args.key?(:publisher) @schema_capabilities = args[:schema_capabilities] if args.key?(:schema_capabilities) @update_time = args[:update_time] if args.key?(:update_time) @updater = args[:updater] if args.key?(:updater) end |