Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
Basic properties of the choice.
Instance Attribute Summary collapse
-
#badge_config ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaBadgeConfig
Badge status of the label.
-
#description ⇒ String
The description of this label.
-
#display_name ⇒ String
Required.
-
#insert_before_choice ⇒ String
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties
constructor
A new instance of GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties
Returns a new instance of GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties.
2027 2028 2029 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2027 def initialize(**args) update!(**args) end |
Instance Attribute Details
#badge_config ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaBadgeConfig
Badge status of the label.
Corresponds to the JSON property badgeConfig
2009 2010 2011 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2009 def badge_config @badge_config end |
#description ⇒ String
The description of this label.
Corresponds to the JSON property description
2014 2015 2016 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2014 def description @description end |
#display_name ⇒ String
Required. The display text to show in the UI identifying this field.
Corresponds to the JSON property displayName
2019 2020 2021 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2019 def display_name @display_name end |
#insert_before_choice ⇒ String
Input only. Insert or move this choice before the indicated choice. If empty,
the choice is placed at the end of the list.
Corresponds to the JSON property insertBeforeChoice
2025 2026 2027 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2025 def insert_before_choice @insert_before_choice end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2032 2033 2034 2035 2036 2037 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2032 def update!(**args) @badge_config = args[:badge_config] if args.key?(:badge_config) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @insert_before_choice = args[:insert_before_choice] if args.key?(:insert_before_choice) end |