Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelLock
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelLock
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
A lock that can be applied to a label, field, or choice.
Instance Attribute Summary collapse
-
#capabilities ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelLockCapabilities
A description of a user's capabilities on a label lock.
-
#choice_id ⇒ String
The ID of the selection field choice that should be locked.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
-
#delete_time ⇒ String
Output only.
-
#field_id ⇒ String
The ID of the field that should be locked.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelLock
constructor
A new instance of GoogleAppsDriveLabelsV2betaLabelLock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLabelLock
Returns a new instance of GoogleAppsDriveLabelsV2betaLabelLock.
2565 2566 2567 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capabilities ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelLockCapabilities
A description of a user's capabilities on a label lock.
Corresponds to the JSON property capabilities
2525 2526 2527 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2525 def capabilities @capabilities end |
#choice_id ⇒ String
The ID of the selection field choice that should be locked. If present,
field_id must also be present.
Corresponds to the JSON property choiceId
2531 2532 2533 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2531 def choice_id @choice_id end |
#create_time ⇒ String
Output only. The time this label lock was created.
Corresponds to the JSON property createTime
2536 2537 2538 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2536 def create_time @create_time end |
#creator ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUserInfo
Information about a user.
Corresponds to the JSON property creator
2541 2542 2543 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2541 def creator @creator end |
#delete_time ⇒ String
Output only. A timestamp indicating when this label lock was scheduled for
deletion. Present only if this label lock is in the DELETING state.
Corresponds to the JSON property deleteTime
2547 2548 2549 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2547 def delete_time @delete_time end |
#field_id ⇒ String
The ID of the field that should be locked. Empty if the whole label should be
locked.
Corresponds to the JSON property fieldId
2553 2554 2555 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2553 def field_id @field_id end |
#name ⇒ String
Output only. Resource name of this label lock.
Corresponds to the JSON property name
2558 2559 2560 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2558 def name @name end |
#state ⇒ String
Output only. This label lock's state.
Corresponds to the JSON property state
2563 2564 2565 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2563 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2570 def update!(**args) @capabilities = args[:capabilities] if args.key?(:capabilities) @choice_id = args[:choice_id] if args.key?(:choice_id) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @delete_time = args[:delete_time] if args.key?(:delete_time) @field_id = args[:field_id] if args.key?(:field_id) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |