Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLifecycle
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLifecycle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
The lifecycle state of an object, such as label, field, or choice. For more
information, see Label lifecycle. The lifecycle enforces the following
transitions: * UNPUBLISHED_DRAFT (starting state) * UNPUBLISHED_DRAFT ->
PUBLISHED * UNPUBLISHED_DRAFT -> (Deleted) * PUBLISHED -> DISABLED *
DISABLED -> PUBLISHED * DISABLED -> (Deleted) The published and disabled
states have some distinct characteristics: * Published: Some kinds of
changes might be made to an object in this state, in which case
has_unpublished_changes will be true. Also, some kinds of changes aren't
permitted. Generally, any change that would invalidate or cause new
restrictions on existing metadata related to the label are rejected. *
Disabled: When disabled, the configured DisabledPolicy takes effect.
Instance Attribute Summary collapse
-
#disabled_policy ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLifecycleDisabledPolicy
The policy that governs how to treat a disabled label, field, or selection choice in different contexts.
-
#has_unpublished_changes ⇒ Boolean
(also: #has_unpublished_changes?)
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLifecycle
constructor
A new instance of GoogleAppsDriveLabelsV2betaLifecycle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaLifecycle
Returns a new instance of GoogleAppsDriveLabelsV2betaLifecycle.
2758 2759 2760 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2758 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disabled_policy ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLifecycleDisabledPolicy
The policy that governs how to treat a disabled label, field, or selection
choice in different contexts.
Corresponds to the JSON property disabledPolicy
2744 2745 2746 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2744 def disabled_policy @disabled_policy end |
#has_unpublished_changes ⇒ Boolean Also known as: has_unpublished_changes?
Output only. Whether the object associated with this lifecycle has unpublished
changes.
Corresponds to the JSON property hasUnpublishedChanges
2750 2751 2752 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2750 def has_unpublished_changes @has_unpublished_changes end |
#state ⇒ String
Output only. The state of the object associated with this lifecycle.
Corresponds to the JSON property state
2756 2757 2758 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2756 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2763 2764 2765 2766 2767 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 2763 def update!(**args) @disabled_policy = args[:disabled_policy] if args.key?(:disabled_policy) @has_unpublished_changes = args[:has_unpublished_changes] if args.key?(:has_unpublished_changes) @state = args[:state] if args.key?(:state) end |