Class: Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUpdateLabelEnabledAppSettingsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaUpdateLabelEnabledAppSettingsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2beta/classes.rb,
lib/google/apis/drivelabels_v2beta/representations.rb,
lib/google/apis/drivelabels_v2beta/representations.rb
Overview
Request to update the EnabledAppSettings of the given label. This change is
not revisioned, doesn't require publishing, and takes effect immediately. \
Instance Attribute Summary collapse
-
#enabled_app_settings ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelEnabledAppSettings
Describes the Google Workspace apps in which the label can be used.
-
#language_code ⇒ String
Optional.
-
#use_admin_access ⇒ Boolean
(also: #use_admin_access?)
Optional.
-
#view ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaUpdateLabelEnabledAppSettingsRequest
constructor
A new instance of GoogleAppsDriveLabelsV2betaUpdateLabelEnabledAppSettingsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2betaUpdateLabelEnabledAppSettingsRequest
Returns a new instance of GoogleAppsDriveLabelsV2betaUpdateLabelEnabledAppSettingsRequest.
3121 3122 3123 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_app_settings ⇒ Google::Apis::DrivelabelsV2beta::GoogleAppsDriveLabelsV2betaLabelEnabledAppSettings
Describes the Google Workspace apps in which the label can be used.
Corresponds to the JSON property enabledAppSettings
3099 3100 3101 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3099 def enabled_app_settings @enabled_app_settings end |
#language_code ⇒ String
Optional. The BCP-47 language code to use for evaluating localized field
labels. When not specified, values in the default configured language will be
used.
Corresponds to the JSON property languageCode
3106 3107 3108 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3106 def language_code @language_code end |
#use_admin_access ⇒ Boolean Also known as: use_admin_access?
Optional. Set to true in order to use the user's admin credentials. The
server will verify the user is an admin for the label before allowing access.
Corresponds to the JSON property useAdminAccess
3112 3113 3114 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3112 def use_admin_access @use_admin_access end |
#view ⇒ String
Optional. When specified, only certain fields belonging to the indicated view
will be returned.
Corresponds to the JSON property view
3119 3120 3121 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3119 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3126 3127 3128 3129 3130 3131 |
# File 'lib/google/apis/drivelabels_v2beta/classes.rb', line 3126 def update!(**args) @enabled_app_settings = args[:enabled_app_settings] if args.key?(:enabled_app_settings) @language_code = args[:language_code] if args.key?(:language_code) @use_admin_access = args[:use_admin_access] if args.key?(:use_admin_access) @view = args[:view] if args.key?(:view) end |